==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/da.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Opgaver",
    "Due yesterday" : "Forfaldsdato var i går",
    "Due today" : "Forfaldsdato er i dag",
    "Due tomorrow" : "Forfaldsdato er i morgen",
    "Due on" : "Forfaldsdatoen er",
    "Started yesterday" : "Påbegyndt i går",
    "Starts today" : "Starter i dag",
    "Starts tomorrow" : "Starter i morgen",
    "Started on" : "Startdatoen var",
    "Starts on" : "Startdatoen er",
    "[Remind me yesterday at ]HH:mm" : "[Påmind mig i går kl. ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Påmind mig i dag kl. ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Påmind mig i morgen kl. ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Påmind mig den ]DD. MM YYYY,[ kl. ]HH:mm",
    "Yesterday" : "I går",
    "Today" : "I dag",
    "Tomorrow" : "I morgen",
    "in %s" : "i %s",
    "%s ago" : "%s siden",
    "seconds" : "sekunder",
    "a minute" : "et minut",
    "%d minutes" : "%d minutter",
    "an hour" : "en time",
    "%d hours" : "%d timer",
    "a day" : "en dag",
    "%d days" : "%d dage",
    "a month" : "en måned",
    "%d months" : "%d måneder",
    "a year" : "et år",
    "%d years" : "%d år",
    "week" : "uge",
    "weeks" : "uger",
    "day" : "dag",
    "days" : "dage",
    "hour" : "time",
    "hours" : "timer",
    "minute" : "minut",
    "minutes" : "minutter",
    "second" : "sekund",
    "before beginning" : "før start",
    "after beginning" : "efter start",
    "before end" : "før afslutning",
    "after end" : "efter afslutning",
    "Comment" : "Kommentér",
    "Add a comment" : "Tilføj en kommentar",
    "This will delete the Calendar \"%s\" and all of its entries." : "Dette vil slette kalenderen \"%s\" og alle dens poster.",
    "The name \"%s\" is already used." : "Navnet \"%s\" er allerede i brug.",
    "An empty name is not allowed." : "Et tomt navn er ikke tilladt.",
    "Hidden" : "Skjult",
    "Visible" : "Synlig",
    "Automatic" : "Automatisk",
    "Sunday" : "Søndag",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Add an important item in \"%s\"..." : "Tilføj et vigtigt element i \"%s\"...",
    "Add an item due today in \"%s\"..." : "Tilføj et element som forfalder i dag i \"%s\"...",
    "Add an item in \"%s\"..." : "Tilføj et element i \"%s\"...",
    "Add a current item in \"%s\"..." : "Tilføj et nuværende element i \"%s\"...",
    "Add a subtask to \"%s\"..." : "Tilføj en delopgave til \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n fuldført opgave","%n fuldførte opgaver"],
    "Hours" : "Timer",
    "Minutes" : "Minutter",
    "Set due date" : "Angiv en forfaldsdato",
    "%s %% completed" : "%s %% er fuldført",
    "priority %s: " : "prioritet %s: ",
    "high" : "høj",
    "medium" : "medium",
    "low" : "lav",
    "no priority assigned" : "ingen prioritet defineret",
    "Remind me" : "Påmind mig",
    "at the end" : "mod slutningen",
    "at the beginning" : "i begyndelsen",
    "Set start date" : "Angiv startdato",
    "{calendar} shared by {owner}" : "{calendar} delt af {owner}",
    "Unnamed" : "Unavngiven",
    "Important" : "Vigtigt",
    "Week" : "Uge",
    "All" : "Alle",
    "Current" : "Nuværende",
    "Completed" : "Fuldført",
    "Delete" : "Slet",
    "Cancel" : "Annullér",
    "Edit" : "Redigér",
    "Link" : "Link",
    "Download" : "Hent",
    "Save" : "Gem",
    "Add List..." : "Tilføj liste...",
    "New List" : "Ny liste",
    "Settings" : "Indstillinger",
    "Start of week" : "Ugens start",
    "Visibility of Smart Collections" : "Synlighed for smarte samlinger",
    "Change sort order" : "Skift sorteringsrækkefølge",
    "Default" : "Standard",
    "Due date" : "Forfaldsdato",
    "Start date" : "Start dato",
    "Priority" : "Prioritet",
    "Alphabetically" : "Alfabetisk",
    "Manually" : "Manuelt",
    "Load remaining completed tasks." : "Indlæs resten af de fuldførte opgaver.",
    "All day" : "Hele dagen",
    "(New category)" : "(Ny kategori)",
    "Select categories..." : "Vælg kategorier...",
    "Loading the task..." : "Indlæser opgaven ...",
    "Task not found!" : "Opgaven blev ikke fundet!",
    "add a subtask to" : "tilføj en delopgave til"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.9.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/da.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Opgaver",
    "Due yesterday" : "Forfaldsdato var i går",
    "Due today" : "Forfaldsdato er i dag",
    "Due tomorrow" : "Forfaldsdato er i morgen",
    "Due on" : "Forfaldsdatoen er",
    "Started yesterday" : "Påbegyndt i går",
    "Starts today" : "Starter i dag",
    "Starts tomorrow" : "Starter i morgen",
    "Started on" : "Startdatoen var",
    "Starts on" : "Startdatoen er",
    "[Remind me yesterday at ]HH:mm" : "[Påmind mig i går kl. ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Påmind mig i dag kl. ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Påmind mig i morgen kl. ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Påmind mig den ]DD. MM YYYY,[ kl. ]HH:mm",
    "Yesterday" : "I går",
    "Today" : "I dag",
    "Tomorrow" : "I morgen",
    "in %s" : "i %s",
    "%s ago" : "%s siden",
    "seconds" : "sekunder",
    "a minute" : "et minut",
    "%d minutes" : "%d minutter",
    "an hour" : "en time",
    "%d hours" : "%d timer",
    "a day" : "en dag",
    "%d days" : "%d dage",
    "a month" : "en måned",
    "%d months" : "%d måneder",
    "a year" : "et år",
    "%d years" : "%d år",
    "week" : "uge",
    "weeks" : "uger",
    "day" : "dag",
    "days" : "dage",
    "hour" : "time",
    "hours" : "timer",
    "minute" : "minut",
    "minutes" : "minutter",
    "second" : "sekund",
    "before beginning" : "før start",
    "after beginning" : "efter start",
    "before end" : "før afslutning",
    "after end" : "efter afslutning",
    "Comment" : "Kommentér",
    "Add a comment" : "Tilføj en kommentar",
    "This will delete the Calendar \"%s\" and all of its entries." : "Dette vil slette kalenderen \"%s\" og alle dens poster.",
    "The name \"%s\" is already used." : "Navnet \"%s\" er allerede i brug.",
    "An empty name is not allowed." : "Et tomt navn er ikke tilladt.",
    "Hidden" : "Skjult",
    "Visible" : "Synlig",
    "Automatic" : "Automatisk",
    "Sunday" : "Søndag",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Add an important item in \"%s\"..." : "Tilføj et vigtigt element i \"%s\"...",
    "Add an item due today in \"%s\"..." : "Tilføj et element som forfalder i dag i \"%s\"...",
    "Add an item in \"%s\"..." : "Tilføj et element i \"%s\"...",
    "Add a current item in \"%s\"..." : "Tilføj et nuværende element i \"%s\"...",
    "Add a subtask to \"%s\"..." : "Tilføj en delopgave til \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n fuldført opgave","%n fuldførte opgaver"],
    "Hours" : "Timer",
    "Minutes" : "Minutter",
    "Set due date" : "Angiv en forfaldsdato",
    "%s %% completed" : "%s %% er fuldført",
    "priority %s: " : "prioritet %s: ",
    "high" : "høj",
    "medium" : "medium",
    "low" : "lav",
    "no priority assigned" : "ingen prioritet defineret",
    "Remind me" : "Påmind mig",
    "at the end" : "mod slutningen",
    "at the beginning" : "i begyndelsen",
    "Set start date" : "Angiv startdato",
    "{calendar} shared by {owner}" : "{calendar} delt af {owner}",
    "Unnamed" : "Unavngiven",
    "Important" : "Vigtigt",
    "Week" : "Uge",
    "All" : "Alle",
    "Current" : "Nuværende",
    "Completed" : "Fuldført",
    "Delete" : "Slet",
    "Cancel" : "Annullér",
    "Edit" : "Redigér",
    "Link" : "Link",
    "Download" : "Hent",
    "Save" : "Gem",
    "Add List..." : "Tilføj liste...",
    "New List" : "Ny liste",
    "Settings" : "Indstillinger",
    "Start of week" : "Ugens start",
    "Visibility of Smart Collections" : "Synlighed for smarte samlinger",
    "Change sort order" : "Skift sorteringsrækkefølge",
    "Default" : "Standard",
    "Due date" : "Forfaldsdato",
    "Start date" : "Start dato",
    "Priority" : "Prioritet",
    "Alphabetically" : "Alfabetisk",
    "Manually" : "Manuelt",
    "Load remaining completed tasks." : "Indlæs resten af de fuldførte opgaver.",
    "Task is completed" : "Denne opgave er udført",
    "All day" : "Hele dagen",
    "(New category)" : "(Ny kategori)",
    "Select categories..." : "Vælg kategorier...",
    "Loading the task..." : "Indlæser opgaven ...",
    "Task not found!" : "Opgaven blev ikke fundet!",
    "add a subtask to" : "tilføj en delopgave til",
    "Toggle subtasks" : "Toggle delopgaver",
    "Toggle completed subtasks" : "Toggle fuldførte delopgaver"
},
"nplurals=2; plural=(n != 1);");
